@@ -40,7 +40,7 @@ use Exception::Class (
 	},
 );
 
-our $VERSION = '2.10';
+our $VERSION = '2.11';
 
 sub set_time {
 	my ( $self, %conf ) = @_;
@@ -252,9 +252,6 @@ sub place {
 		);
 	}
 
-	$place = encode( 'ISO-8859-15', $place );
-	$stop  = encode( 'ISO-8859-15', $stop );
-
 	$type //= 'stop';
 
 	@{ $self->{post} }{ "place_${which}", "name_${which}" } = ( $place, $stop );
@@ -399,6 +396,10 @@ sub create_post {
 		$self->with_bike(1);
 	}
 
+	for my $val ( values %{ $self->{post} } ) {
+		$val = encode( 'ISO-8859-15', $val );
+	}
+
 	return;
 }
 
@@ -593,6 +594,7 @@ sub parse_xml_part {
 			departure_stop     => $e_dep->getAttribute('name'),
 			departure_platform => $e_dep->getAttribute('platformName'),
 			train_line         => $e_mot->getAttribute('name'),
+			train_product      => $e_mot->getAttribute('productName'),
 			train_destination  => $e_mot->getAttribute('destination'),
 			arrival_date       => $self->itddate_str($e_adate),
 			arrival_time       => $self->itdtime_str($e_atime),
@@ -853,7 +855,7 @@ Travel::Routing::DE::EFA - unofficial interface to EFA-based itinerary services
 
 =head1 VERSION
 
-version 2.10
+version 2.11
 
 =head1 DESCRIPTION
 
